==> jscad__svg-deserializer-2.4.1.jar: META-INF/resources/webjars/jscad__svg-deserializer/2.4.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.4.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.4.0...@jscad/svg-deserializer@2.4.1) (2021-10-04)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.4.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.3.0...@jscad/svg-deserializer@2.4.0) (2021-09-27)


### Bug Fixes

* **modeling:** corrected concat to ignore duplicate points ([#913](https://github.com/jscad/OpenJSCAD.org/issues/913))corrected appendArc to maintain last point ([3eea3ef](https://github.com/jscad/OpenJSCAD.org/commit/3eea3efed3b3d4bacb49c1ee4691bfc159b08261))


### Features

* **svg-deserializer:** reworked to use saxes library, and standard module layout ([56f5725](https://github.com/jscad/OpenJSCAD.org/commit/56f572518c85d767ac680aa2da1af46c4847e63c))





# [2.3.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.4...@jscad/svg-deserializer@2.3.0) (2021-09-09)


### Features

* **svg-deserializer:** added pathSelfClosed option to control construction of overlapping paths ([043f59d](https://github.com/jscad/OpenJSCAD.org/commit/043f59d928fcf397b0bb23e744e35d7eda5be626))





## [2.2.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.3...@jscad/svg-deserializer@2.2.4) (2021-06-20)

**Note:** Version bump only for package @jscad/svg-deserializer





## [2.2.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.2...@jscad/svg-deserializer@2.2.3) (2021-06-11)


### Bug Fixes

* **svg-deserializer:** corrected conversion of stroke/fill to geometry color ([73f4d50](https://github.com/jscad/OpenJSCAD.org/commit/73f4d50e2622a9ba86fd5abc747778795391382b))





## [2.2.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.1...@jscad/svg-deserializer@2.2.2) (2021-06-01)

**Note:** Version bump only for package @jscad/svg-deserializer





## [2.2.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.0...@jscad/svg-deserializer@2.2.1) (2021-04-20)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.2.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.0...@jscad/svg-deserializer@2.2.0) (2021-04-17)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))
* **svg-deserializer:** add support for new segments option ([9bdc7f5](https://github.com/jscad/OpenJSCAD.org/commit/9bdc7f59dff8847c250c8c63a91babb1a69a03a6))
* **svg-deserializer:** V2 - enhance SVG deserializer for mirror transforms ([#733](https://github.com/jscad/OpenJSCAD.org/issues/733)) ([a50b584](https://github.com/jscad/OpenJSCAD.org/commit/a50b5847645009a385636852398257b12c6b0949))





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.0...@jscad/svg-deserializer@2.1.0) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))
* **svg-deserializer:** add support for new segments option ([9bdc7f5](https://github.com/jscad/OpenJSCAD.org/commit/9bdc7f59dff8847c250c8c63a91babb1a69a03a6))
* **svg-deserializer:** V2 - enhance SVG deserializer for mirror transforms ([#733](https://github.com/jscad/OpenJSCAD.org/issues/733)) ([a50b584](https://github.com/jscad/OpenJSCAD.org/commit/a50b5847645009a385636852398257b12c6b0949))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.11...@jscad/svg-deserializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.10...@jscad/svg-deserializer@2.0.0-alpha.11) (2021-03-07)


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.9...@jscad/svg-deserializer@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.8...@jscad/svg-deserializer@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.7...@jscad/svg-deserializer@2.0.0-alpha.8) (2020-12-04)


### Features

* **svg-deserializer:** V2 - enhance SVG deserializer for mirror transforms ([#733](https://github.com/jscad/OpenJSCAD.org/issues/733)) ([a50b584](https://github.com/jscad/OpenJSCAD.org/commit/a50b5847645009a385636852398257b12c6b0949))





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.6...@jscad/svg-deserializer@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.5...@jscad/svg-deserializer@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/issues/705)) ([62017a4](https://github.com/jscad/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.4...@jscad/svg-deserializer@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.4](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.3...@jscad/svg-deserializer@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.3](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.2...@jscad/svg-deserializer@2.0.0-alpha.3) (2020-09-19)


### Features

* **svg-deserializer:** add support for new segments option ([9bdc7f5](https://github.com/jscad/commit/9bdc7f59dff8847c250c8c63a91babb1a69a03a6))





# [2.0.0-alpha.2](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.1...@jscad/svg-deserializer@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.1](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.0...@jscad/svg-deserializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/svg-deserializer





# 2.0.0-alpha.0 (2020-08-13)


### Bug Fixes

* **colors:** colorize is now immutable & returns new geometries ([#566](https://github.com/jscad/issues/566)) ([916824c](https://github.com/jscad/commit/916824c63a0bf8896d1b6f85a82b129a013bec58))
* **svg-deserializer:** adds require / export to the translation & some minor fixes & tweaks([#524](https://github.com/jscad/issues/524)) ([5ee1509](https://github.com/jscad/commit/5ee15099552c2201259eaa1f4664cd83d761af4b))
* **svg-deserializer:** corrected svg transforms while instantiating shapes
* **svg-deserializer:** corrected conversion of shapes when target is geometry


### Features

* **svg-deserializer:** overhaul for V2 (#463)
* **io:** change api to deserialize(options, source)





<a name="0.4.3"></a>
## [0.4.3](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.4.2...@jscad/svg-deserializer@0.4.3) (2018-11-25)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.4.2"></a>
## [0.4.2](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.4.1...@jscad/svg-deserializer@0.4.2) (2018-09-02)


### Bug Fixes

* **svg deserializer:** fixed svg-deserializer to work with Inkscape files ([#72](https://github.com/jscad/io/issues/72)) ([f35ea5e](https://github.com/jscad/io/commit/f35ea5e))




<a name="0.4.1"></a>
## [0.4.1](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.4.0...@jscad/svg-deserializer@0.4.1) (2017-12-14)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.4.0"></a>
# [0.4.0](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.3.0...@jscad/svg-deserializer@0.4.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.3.0"></a>
# [0.3.0](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.3...@jscad/svg-deserializer@0.3.0) (2017-11-14)


### Features

* **deserializers:** added csg output capabilities to amf & obj deserializers & basic tests ([#47](https://github.com/jscad/io/issues/47)) ([abf3040](https://github.com/jscad/io/commit/abf3040))




<a name="0.2.3"></a>
## [0.2.3](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.2...@jscad/svg-deserializer@0.2.3) (2017-11-04)


### Bug Fixes

* **svg transforms:** fixes weird new issue with undefined vs null transforms ([#46](https://github.com/jscad/io/issues/46)) ([4a47f00](https://github.com/jscad/io/commit/4a47f00))




<a name="0.2.2"></a>
## [0.2.2](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.1...@jscad/svg-deserializer@0.2.2) (2017-11-04)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.2.1"></a>
## [0.2.1](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.0...@jscad/svg-deserializer@0.2.1) (2017-10-10)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.2.0"></a>
# 0.2.0 (2017-10-10)


### Bug Fixes

* **svg-deserializer:** m/M commands can have implicit lineTo ([#20](https://github.com/jscad/io/issues/20)) ([969d0da](https://github.com/jscad/io/commit/969d0da))


### Features

* **svg-deserializer:** add ability to deserialize svg data to csg objects directly ([#25](https://github.com/jscad/io/issues/25)) ([cb0ce71](https://github.com/jscad/io/commit/cb0ce71))

==> jscad__svg-deserializer-2.4.2.jar: META-INF/resources/webjars/jscad__svg-deserializer/2.4.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.4.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.4.1...@jscad/svg-deserializer@2.4.2) (2021-10-17)

**Note:** Version bump only for package @jscad/svg-deserializer





## [2.4.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.4.0...@jscad/svg-deserializer@2.4.1) (2021-10-04)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.4.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.3.0...@jscad/svg-deserializer@2.4.0) (2021-09-27)


### Bug Fixes

* **modeling:** corrected concat to ignore duplicate points ([#913](https://github.com/jscad/OpenJSCAD.org/issues/913))corrected appendArc to maintain last point ([3eea3ef](https://github.com/jscad/OpenJSCAD.org/commit/3eea3efed3b3d4bacb49c1ee4691bfc159b08261))


### Features

* **svg-deserializer:** reworked to use saxes library, and standard module layout ([56f5725](https://github.com/jscad/OpenJSCAD.org/commit/56f572518c85d767ac680aa2da1af46c4847e63c))





# [2.3.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.4...@jscad/svg-deserializer@2.3.0) (2021-09-09)


### Features

* **svg-deserializer:** added pathSelfClosed option to control construction of overlapping paths ([043f59d](https://github.com/jscad/OpenJSCAD.org/commit/043f59d928fcf397b0bb23e744e35d7eda5be626))





## [2.2.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.3...@jscad/svg-deserializer@2.2.4) (2021-06-20)

**Note:** Version bump only for package @jscad/svg-deserializer





## [2.2.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.2...@jscad/svg-deserializer@2.2.3) (2021-06-11)


### Bug Fixes

* **svg-deserializer:** corrected conversion of stroke/fill to geometry color ([73f4d50](https://github.com/jscad/OpenJSCAD.org/commit/73f4d50e2622a9ba86fd5abc747778795391382b))





## [2.2.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.1...@jscad/svg-deserializer@2.2.2) (2021-06-01)

**Note:** Version bump only for package @jscad/svg-deserializer





## [2.2.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.2.0...@jscad/svg-deserializer@2.2.1) (2021-04-20)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.2.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.0...@jscad/svg-deserializer@2.2.0) (2021-04-17)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))
* **svg-deserializer:** add support for new segments option ([9bdc7f5](https://github.com/jscad/OpenJSCAD.org/commit/9bdc7f59dff8847c250c8c63a91babb1a69a03a6))
* **svg-deserializer:** V2 - enhance SVG deserializer for mirror transforms ([#733](https://github.com/jscad/OpenJSCAD.org/issues/733)) ([a50b584](https://github.com/jscad/OpenJSCAD.org/commit/a50b5847645009a385636852398257b12c6b0949))





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.0...@jscad/svg-deserializer@2.1.0) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))
* **svg-deserializer:** add support for new segments option ([9bdc7f5](https://github.com/jscad/OpenJSCAD.org/commit/9bdc7f59dff8847c250c8c63a91babb1a69a03a6))
* **svg-deserializer:** V2 - enhance SVG deserializer for mirror transforms ([#733](https://github.com/jscad/OpenJSCAD.org/issues/733)) ([a50b584](https://github.com/jscad/OpenJSCAD.org/commit/a50b5847645009a385636852398257b12c6b0949))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.11...@jscad/svg-deserializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.10...@jscad/svg-deserializer@2.0.0-alpha.11) (2021-03-07)


### Features

* **modeling:** V2 : rename option to align and center ([#775](https://github.com/jscad/OpenJSCAD.org/issues/775)) ([c5b0f48](https://github.com/jscad/OpenJSCAD.org/commit/c5b0f48bbd980b59876d73b673a0e3bef44d2b30))





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.9...@jscad/svg-deserializer@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.8...@jscad/svg-deserializer@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.7...@jscad/svg-deserializer@2.0.0-alpha.8) (2020-12-04)


### Features

* **svg-deserializer:** V2 - enhance SVG deserializer for mirror transforms ([#733](https://github.com/jscad/OpenJSCAD.org/issues/733)) ([a50b584](https://github.com/jscad/OpenJSCAD.org/commit/a50b5847645009a385636852398257b12c6b0949))





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/svg-deserializer@2.0.0-alpha.6...@jscad/svg-deserializer@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.5...@jscad/svg-deserializer@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/issues/705)) ([62017a4](https://github.com/jscad/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.4...@jscad/svg-deserializer@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.4](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.3...@jscad/svg-deserializer@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.3](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.2...@jscad/svg-deserializer@2.0.0-alpha.3) (2020-09-19)


### Features

* **svg-deserializer:** add support for new segments option ([9bdc7f5](https://github.com/jscad/commit/9bdc7f59dff8847c250c8c63a91babb1a69a03a6))





# [2.0.0-alpha.2](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.1...@jscad/svg-deserializer@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/svg-deserializer





# [2.0.0-alpha.1](https://github.com/jscad/compare/@jscad/svg-deserializer@2.0.0-alpha.0...@jscad/svg-deserializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/svg-deserializer





# 2.0.0-alpha.0 (2020-08-13)


### Bug Fixes

* **colors:** colorize is now immutable & returns new geometries ([#566](https://github.com/jscad/issues/566)) ([916824c](https://github.com/jscad/commit/916824c63a0bf8896d1b6f85a82b129a013bec58))
* **svg-deserializer:** adds require / export to the translation & some minor fixes & tweaks([#524](https://github.com/jscad/issues/524)) ([5ee1509](https://github.com/jscad/commit/5ee15099552c2201259eaa1f4664cd83d761af4b))
* **svg-deserializer:** corrected svg transforms while instantiating shapes
* **svg-deserializer:** corrected conversion of shapes when target is geometry


### Features

* **svg-deserializer:** overhaul for V2 (#463)
* **io:** change api to deserialize(options, source)





<a name="0.4.3"></a>
## [0.4.3](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.4.2...@jscad/svg-deserializer@0.4.3) (2018-11-25)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.4.2"></a>
## [0.4.2](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.4.1...@jscad/svg-deserializer@0.4.2) (2018-09-02)


### Bug Fixes

* **svg deserializer:** fixed svg-deserializer to work with Inkscape files ([#72](https://github.com/jscad/io/issues/72)) ([f35ea5e](https://github.com/jscad/io/commit/f35ea5e))




<a name="0.4.1"></a>
## [0.4.1](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.4.0...@jscad/svg-deserializer@0.4.1) (2017-12-14)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.4.0"></a>
# [0.4.0](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.3.0...@jscad/svg-deserializer@0.4.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.3.0"></a>
# [0.3.0](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.3...@jscad/svg-deserializer@0.3.0) (2017-11-14)


### Features

* **deserializers:** added csg output capabilities to amf & obj deserializers & basic tests ([#47](https://github.com/jscad/io/issues/47)) ([abf3040](https://github.com/jscad/io/commit/abf3040))




<a name="0.2.3"></a>
## [0.2.3](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.2...@jscad/svg-deserializer@0.2.3) (2017-11-04)


### Bug Fixes

* **svg transforms:** fixes weird new issue with undefined vs null transforms ([#46](https://github.com/jscad/io/issues/46)) ([4a47f00](https://github.com/jscad/io/commit/4a47f00))




<a name="0.2.2"></a>
## [0.2.2](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.1...@jscad/svg-deserializer@0.2.2) (2017-11-04)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.2.1"></a>
## [0.2.1](https://github.com/jscad/io/compare/@jscad/svg-deserializer@0.2.0...@jscad/svg-deserializer@0.2.1) (2017-10-10)




**Note:** Version bump only for package @jscad/svg-deserializer

<a name="0.2.0"></a>
# 0.2.0 (2017-10-10)


### Bug Fixes

* **svg-deserializer:** m/M commands can have implicit lineTo ([#20](https://github.com/jscad/io/issues/20)) ([969d0da](https://github.com/jscad/io/commit/969d0da))


### Features

* **svg-deserializer:** add ability to deserialize svg data to csg objects directly ([#25](https://github.com/jscad/io/issues/25)) ([cb0ce71](https://github.com/jscad/io/commit/cb0ce71))
